import { CommentResponse, CreateComment, CreateCommentLike, DeleteComment, EditComment, GetComments, GetCommentsResponse, MarkCommentAsRead, RemoveComment, SaveComment } from './interfaces/api/comment';
import { AddModToCommunity, AddModToCommunityResponse, BanFromCommunity, BanFromCommunityResponse, CommunityJoin, CommunityJoinResponse, CommunityResponse, CreateCommunity, DeleteCommunity, EditCommunity, FollowCommunity, GetCommunity, GetCommunityResponse, GetFollowedCommunities, GetFollowedCommunitiesResponse, ListCommunities, ListCommunitiesResponse, RemoveCommunity, TransferCommunity } from './interfaces/api/community';
import { CreatePost, CreatePostLike, DeletePost, EditPost, GetPost, GetPostResponse, GetPosts, GetPostsResponse, LockPost, PostJoin, PostJoinResponse, PostResponse, RemovePost, SavePost, StickyPost } from './interfaces/api/post';
import { CreateSite, EditSite, GetModlog, GetModlogResponse, GetSite, GetSiteConfig, GetSiteConfigResponse, GetSiteResponse, ListCategoriesResponse, SaveSiteConfig, Search, SearchResponse, SiteResponse, TransferSite } from './interfaces/api/site';
import { AddAdmin, AddAdminResponse, BanUser, BanUserResponse, CreatePrivateMessage, DeleteAccount, DeletePrivateMessage, EditPrivateMessage, GetCaptchaResponse, GetPrivateMessages, GetReplies, GetRepliesResponse, GetUserDetails, GetUserDetailsResponse, GetUserMentions, GetUserMentionsResponse, Login, LoginResponse, MarkAllAsRead, MarkPrivateMessageAsRead, MarkUserMentionAsRead, PasswordChange, PasswordReset, PasswordResetResponse, PrivateMessageResponse, PrivateMessagesResponse, Register, SaveUserSettings, UserJoin, UserJoinResponse, UserMentionResponse } from './interfaces/api/user';
export declare class LemmyHttp {
    private baseUrl;
    private headers;
    constructor(baseUrl: string, headers?: {
        [key: string]: string;
    });
    getSite(form: GetSite): Promise<GetSiteResponse>;
    createSite(form: CreateSite): Promise<SiteResponse>;
    editSite(form: EditSite): Promise<SiteResponse>;
    transferSite(form: TransferSite): Promise<GetSiteResponse>;
    getSiteConfig(form: GetSiteConfig): Promise<GetSiteConfigResponse>;
    saveSiteConfig(form: SaveSiteConfig): Promise<GetSiteConfigResponse>;
    listCategories(): Promise<ListCategoriesResponse>;
    getModlog(form: GetModlog): Promise<GetModlogResponse>;
    search(form: Search): Promise<SearchResponse>;
    createCommunity(form: CreateCommunity): Promise<CommunityResponse>;
    getCommunity(form: GetCommunity): Promise<GetCommunityResponse>;
    editCommunity(form: EditCommunity): Promise<CommunityResponse>;
    listCommunities(form: ListCommunities): Promise<ListCommunitiesResponse>;
    followCommunity(form: FollowCommunity): Promise<CommunityResponse>;
    deleteCommunity(form: DeleteCommunity): Promise<CommunityResponse>;
    removeCommunity(form: RemoveCommunity): Promise<CommunityResponse>;
    transferCommunity(form: TransferCommunity): Promise<GetCommunityResponse>;
    banFromCommunity(form: BanFromCommunity): Promise<BanFromCommunityResponse>;
    addModToCommunity(form: AddModToCommunity): Promise<AddModToCommunityResponse>;
    createPost(form: CreatePost): Promise<PostResponse>;
    getPost(form: GetPost): Promise<GetPostResponse>;
    editPost(form: EditPost): Promise<PostResponse>;
    deletePost(form: DeletePost): Promise<PostResponse>;
    removePost(form: RemovePost): Promise<PostResponse>;
    lockPost(form: LockPost): Promise<PostResponse>;
    stickyPost(form: StickyPost): Promise<PostResponse>;
    getPosts(form: GetPosts): Promise<GetPostsResponse>;
    likePost(form: CreatePostLike): Promise<PostResponse>;
    savePost(form: SavePost): Promise<PostResponse>;
    createComment(form: CreateComment): Promise<CommentResponse>;
    editComment(form: EditComment): Promise<CommentResponse>;
    deleteComment(form: DeleteComment): Promise<CommentResponse>;
    removeComment(form: RemoveComment): Promise<CommentResponse>;
    markCommentAsRead(form: MarkCommentAsRead): Promise<CommentResponse>;
    likeComment(form: CreateCommentLike): Promise<CommentResponse>;
    saveComment(form: SaveComment): Promise<CommentResponse>;
    getComments(form: GetComments): Promise<GetCommentsResponse>;
    getPrivateMessages(form: GetPrivateMessages): Promise<PrivateMessagesResponse>;
    createPrivateMessage(form: CreatePrivateMessage): Promise<PrivateMessageResponse>;
    editPrivateMessage(form: EditPrivateMessage): Promise<PrivateMessageResponse>;
    deletePrivateMessage(form: DeletePrivateMessage): Promise<PrivateMessageResponse>;
    markPrivateMessageAsRead(form: MarkPrivateMessageAsRead): Promise<PrivateMessageResponse>;
    register(form: Register): Promise<LoginResponse>;
    login(form: Login): Promise<LoginResponse>;
    getUserDetails(form: GetUserDetails): Promise<GetUserDetailsResponse>;
    getUserMentions(form: GetUserMentions): Promise<GetUserMentionsResponse>;
    markUserMentionAsRead(form: MarkUserMentionAsRead): Promise<UserMentionResponse>;
    getReplies(form: GetReplies): Promise<GetRepliesResponse>;
    getFollowedCommunities(form: GetFollowedCommunities): Promise<GetFollowedCommunitiesResponse>;
    userJoin(form: UserJoin): Promise<UserJoinResponse>;
    postJoin(form: PostJoin): Promise<PostJoinResponse>;
    communityJoin(form: CommunityJoin): Promise<CommunityJoinResponse>;
    banUser(form: BanUser): Promise<BanUserResponse>;
    getCaptcha(): Promise<GetCaptchaResponse>;
    deleteAccount(form: DeleteAccount): Promise<LoginResponse>;
    passwordReset(form: PasswordReset): Promise<PasswordResetResponse>;
    passwordChange(form: PasswordChange): Promise<LoginResponse>;
    markAllAsRead(form: MarkAllAsRead): Promise<LoginResponse>;
    saveUserSettings(form: SaveUserSettings): Promise<LoginResponse>;
    addAdmin(form: AddAdmin): Promise<AddAdminResponse>;
    private buildFullUrl;
    private wrapper;
}
